**Example 1: 更新用户组**



Input: 

```
tccli ciam UpdateUserGroup --cli-unfold-argument  \
    --UserStoreId xxx \
    --UserGroupId xxx \
    --DisplayName xxx \
    --Description xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "xxx"
    }
}
```

